@@ -1,7 +1,7 @@
 """python-actransit is a python package for querying API
 data from Alameda-Contra Costa Transit District Transit."""
 
-from . import actransit
-from .actransit import (
-  ACTransit,
-)
\ No newline at end of file
+from actransit import actransit
+from actransit.actransit import (
+    ACTransit,
+)
